# Installation

Start by installing `ipyannotations`:

```
$ pip install ipyannotations
```

If you are using Jupyter Lab, rather than the old Jupyter Notebook application, you will also
have to install two Jupyter Lab extensions:

## Jupyter Lab extensions

```
$ jupyter labextension install @jupyter-widgets/jupyterlab-manager ipycanvas
$ jupyter labextension install @jupyter-widgets/jupyterlab-manager
```
